
#include <xmdv/CParcoordTool.h>
#include <xmdv/CHierParcoord.h>
#include <xmdv/XmdvTool.h>
#include <xmdv/ogl.h>
#include <xmdv/brush.h>

static ARR<double> tmp_min, tmp_max;

CParcoordTool::CParcoordTool(CFlatDisplayInformation* flat_info) : CFlatParcoord(flat_info)
{
}

static void SaveDimMinMax()
{
    // Save the current magnification
    // Setup up full scale magnification
    //
    tmp_min = dataset->dim_min;
    tmp_max = dataset->dim_max;
    dataset->dim_min = dataset->org_dim_min;
    dataset->dim_max = dataset->org_dim_max;
}

static void RestoreDimMinMax()
{
    // Restore magnification
    //
    dataset->dim_min = tmp_min;
    dataset->dim_max = tmp_max;
}

void CParcoordTool::Draw()
{
    if (!dataset) return;

	if ( ! TestDimensionality() )
		return;

    canvas->MakeCurrent();
    canvas->SetBackground(interface_color[BG]);
    canvas->Clear();

    // Setup window parameters.
    // (duplicated from ogl.C)
    //
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    const double BORD = 0.1;
    glOrtho(-BORD,1+BORD,1+BORD,-BORD,-1,1);
    glMatrixMode(GL_MODELVIEW);

    SaveDimMinMax();

    // Paint the current brush
    DrawSingleBrush(curr_brush);

    // Paint the axes and labels
    DrawParcoordAxes(canvas);

    RestoreDimMinMax();
}

void CParcoordTool::InputMouseMotion(int x, int y)
{
    SaveDimMinMax();
    CFlatParcoord::InputMouseMotion(x,y);
    RestoreDimMinMax();
}

void CParcoordTool::InputButtonPress(int button, int x, int y)
{
    SaveDimMinMax();
    CFlatParcoord::InputButtonPress(button,x,y);
    RestoreDimMinMax();
}

void CParcoordTool::InputButtonRelease(int button, int x, int y)
{
    SaveDimMinMax();
    CFlatParcoord::InputButtonRelease(button,x,y);
    RestoreDimMinMax();

    // Remark data after restoring min/max to sieve zoomed-out
    // points.
    appCanvasBrushHasChanged(Togl_Interp(canvas->GetWidget()));
}

